[Libreoffice-commits] .: dbaccess/qa dbaccess/source reportdesign/qa reportdesign/source

Caolán McNamara caolan at kemper.freedesktop.org
Mon Dec 6 01:16:48 PST 2010


 dbaccess/qa/complex/dbaccess/DatabaseDocument.java        |    2 +-
 dbaccess/source/core/api/CacheSet.cxx                     |    4 ++--
 dbaccess/source/core/api/KeySet.cxx                       |    2 +-
 dbaccess/source/core/api/RowSet.hxx                       |    2 +-
 dbaccess/source/core/dataaccess/documenteventexecutor.cxx |    6 +++---
 dbaccess/source/core/misc/DatabaseDataProvider.cxx        |    2 +-
 dbaccess/source/ui/browser/brwctrlr.cxx                   |    4 ++--
 dbaccess/source/ui/browser/sbagrid.cxx                    |    2 +-
 dbaccess/source/ui/browser/sbagrid.src                    |    2 +-
 dbaccess/source/ui/browser/unodatbr.cxx                   |    2 +-
 dbaccess/source/ui/control/dbtreelistbox.cxx              |    2 +-
 dbaccess/source/ui/control/tabletree.cxx                  |    2 +-
 dbaccess/source/ui/dlg/adminpages.hxx                     |    2 +-
 dbaccess/source/ui/inc/JoinController.hxx                 |    4 ++--
 dbaccess/source/ui/inc/datasourcemap.hxx                  |    2 +-
 dbaccess/source/ui/inc/dbadmin.hxx                        |    2 +-
 dbaccess/source/ui/inc/dbu_resource.hrc                   |    2 +-
 dbaccess/source/ui/inc/dbwiz.hxx                          |    2 +-
 dbaccess/source/ui/inc/dbwizsetup.hxx                     |    2 +-
 dbaccess/source/ui/misc/RowSetDrop.cxx                    |    2 +-
 dbaccess/source/ui/querydesign/QueryDesignView.cxx        |    4 ++--
 dbaccess/source/ui/querydesign/SelectionBrowseBox.cxx     |    2 +-
 dbaccess/source/ui/querydesign/SelectionBrowseBox.hxx     |    4 ++--
 dbaccess/source/ui/querydesign/TableWindow.cxx            |    4 ++--
 dbaccess/source/ui/querydesign/TableWindowListBox.cxx     |    4 ++--
 dbaccess/source/ui/querydesign/querycontroller.cxx        |    2 +-
 dbaccess/source/ui/relationdesign/RelationTableView.cxx   |    2 +-
 dbaccess/source/ui/tabledesign/TableController.cxx        |    2 +-
 dbaccess/source/ui/uno/copytablewizard.cxx                |    4 ++--
 dbaccess/source/ui/uno/dbinteraction.hxx                  |    2 +-
 reportdesign/qa/complex/ReportDesignerTest.java           |    2 +-
 reportdesign/source/core/api/ReportDefinition.cxx         |    2 +-
 reportdesign/source/core/misc/conditionalexpression.cxx   |   10 +++++-----
 reportdesign/source/ui/misc/UITools.cxx                   |    4 ++--
 reportdesign/source/ui/report/ViewsWindow.cxx             |    2 +-
 reportdesign/source/ui/report/propbrw.cxx                 |    4 ++--
 36 files changed, 52 insertions(+), 52 deletions(-)

New commits:
commit dea471ac358680e991094d128e9c1262a5077d37
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Sat Dec 4 12:33:49 2010 +0900

    Replace all occured, occurance etc.

diff --git a/dbaccess/qa/complex/dbaccess/DatabaseDocument.java b/dbaccess/qa/complex/dbaccess/DatabaseDocument.java
index 20ae862..0a9e615 100644
--- a/dbaccess/qa/complex/dbaccess/DatabaseDocument.java
+++ b/dbaccess/qa/complex/dbaccess/DatabaseDocument.java
@@ -653,7 +653,7 @@ public class DatabaseDocument extends TestCase implements com.sun.star.document.
                 "  oEvent.EventName = \"OnLoad\"\n" +
                 "  oEvent.Source = ThisComponent\n" +
                 "\n" +
-                "  oCallback.documentEventOccured( oEvent )\n" +
+                "  oCallback.documentEventOccurred( oEvent )\n" +
                 "End Sub\n";
         XModel databaseDoc = impl_createDocWithMacro( libName, moduleName, eventHandlerCode );
         final String documentURL = databaseDoc.getURL();
diff --git a/dbaccess/source/core/api/CacheSet.cxx b/dbaccess/source/core/api/CacheSet.cxx
index af8e6e8..6521f94 100644
--- a/dbaccess/source/core/api/CacheSet.cxx
+++ b/dbaccess/source/core/api/CacheSet.cxx
@@ -137,11 +137,11 @@ OCacheSet::~OCacheSet()
     }
     catch(Exception&)
     {
-        OSL_ENSURE(0,"Exception occured");
+        OSL_ENSURE(0,"Exception occurred");
     }
     catch(...)
     {
-        OSL_ENSURE(0,"Unknown Exception occured");
+        OSL_ENSURE(0,"Unknown Exception occurred");
     }
 
     DBG_DTOR(OCacheSet,NULL);
diff --git a/dbaccess/source/core/api/KeySet.cxx b/dbaccess/source/core/api/KeySet.cxx
index 5d46203..2bbe611 100644
--- a/dbaccess/source/core/api/KeySet.cxx
+++ b/dbaccess/source/core/api/KeySet.cxx
@@ -133,7 +133,7 @@ OKeySet::~OKeySet()
     }
     catch(...)
     {
-        OSL_ENSURE(0,"Unknown Exception occured");
+        OSL_ENSURE(0,"Unknown Exception occurred");
     }
     m_xComposer = NULL;
 
diff --git a/dbaccess/source/core/api/RowSet.hxx b/dbaccess/source/core/api/RowSet.hxx
index 5047acd..4aff134 100644
--- a/dbaccess/source/core/api/RowSet.hxx
+++ b/dbaccess/source/core/api/RowSet.hxx
@@ -179,7 +179,7 @@ namespace dbaccess
                 m_xActiveConnection points to a valid SDB-level connection
 
             @throws com::sun::star::sdb::SQLException
-                if an database-related error occured
+                if an database-related error occurred
 
             @throws com::sun::star::uno::RuntimeException
                 if any of the components involved throws a com::sun::star::uno::RuntimeException
diff --git a/dbaccess/source/core/dataaccess/documenteventexecutor.cxx b/dbaccess/source/core/dataaccess/documenteventexecutor.cxx
index 35262dd..e3301f1 100644
--- a/dbaccess/source/core/dataaccess/documenteventexecutor.cxx
+++ b/dbaccess/source/core/dataaccess/documenteventexecutor.cxx
@@ -163,7 +163,7 @@ namespace dbaccess
         Reference< XEventsSupplier > xEventsSupplier( m_pData->xDocument.get(), UNO_QUERY );
         if ( !xEventsSupplier.is() )
         {
-            OSL_ENSURE( false, "DocumentEventExecutor::documentEventOccured: no document anymore, but still being notified?" );
+            OSL_ENSURE( false, "DocumentEventExecutor::documentEventOccurred: no document anymore, but still being notified?" );
             return;
         }
 
@@ -176,7 +176,7 @@ namespace dbaccess
             {
                 // this is worth an assertion: We are listener at the very same document which we just asked
                 // for its events. So when EventName is fired, why isn't it supported by xDocEvents?
-                OSL_ENSURE( false, "DocumentEventExecutor::documentEventOccured: an unsupported event is notified!" );
+                OSL_ENSURE( false, "DocumentEventExecutor::documentEventOccurred: an unsupported event is notified!" );
                 return;
             }
 
@@ -199,7 +199,7 @@ namespace dbaccess
             bool bNonEmptyScript = sScript.getLength() != 0;
 
             OSL_ENSURE( bDispatchScriptURL && bNonEmptyScript,
-                "DocumentEventExecutor::documentEventOccured: invalid/unsupported script descriptor" );
+                "DocumentEventExecutor::documentEventOccurred: invalid/unsupported script descriptor" );
 
             if ( bDispatchScriptURL && bNonEmptyScript )
             {
diff --git a/dbaccess/source/core/misc/DatabaseDataProvider.cxx b/dbaccess/source/core/misc/DatabaseDataProvider.cxx
index cbd0f7c..9f12bdb 100644
--- a/dbaccess/source/core/misc/DatabaseDataProvider.cxx
+++ b/dbaccess/source/core/misc/DatabaseDataProvider.cxx
@@ -240,7 +240,7 @@ uno::Reference< chart2::data::XDataSource > SAL_CALL DatabaseDataProvider::creat
             {
             }
         }
-        if ( !bRet ) // no command set or an error occured, use Internal data handler
+        if ( !bRet ) // no command set or an error occurred, use Internal data handler
         {
             uno::Reference< lang::XInitialization> xIni(m_xInternal,uno::UNO_QUERY);
             if ( xIni.is() )
diff --git a/dbaccess/source/ui/browser/brwctrlr.cxx b/dbaccess/source/ui/browser/brwctrlr.cxx
index bfa82e3..e952cba 100644
--- a/dbaccess/source/ui/browser/brwctrlr.cxx
+++ b/dbaccess/source/ui/browser/brwctrlr.cxx
@@ -1410,7 +1410,7 @@ IMPL_LINK( SbaXDataBrowserController, OnAsyncDisplayError, void*, /* _pNotIntere
 //------------------------------------------------------------------------------
 void SbaXDataBrowserController::errorOccured(const ::com::sun::star::sdb::SQLErrorEvent& aEvent) throw( RuntimeException )
 {
-    RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "dbaui", "Ocke.Janssen at sun.com", "SbaXDataBrowserController::errorOccured" );
+    RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "dbaui", "Ocke.Janssen at sun.com", "SbaXDataBrowserController::errorOccurred" );
     ::osl::MutexGuard aGuard( getMutex() );
 
     SQLExceptionInfo aInfo( aEvent.Reason );
@@ -1419,7 +1419,7 @@ void SbaXDataBrowserController::errorOccured(const ::com::sun::star::sdb::SQLErr
 
     if ( m_nFormActionNestingLevel )
     {
-        OSL_ENSURE( !m_aCurrentError.isValid(), "SbaXDataBrowserController::errorOccured: can handle one error per transaction only!" );
+        OSL_ENSURE( !m_aCurrentError.isValid(), "SbaXDataBrowserController::errorOccurred: can handle one error per transaction only!" );
         m_aCurrentError = aInfo;
     }
     else
diff --git a/dbaccess/source/ui/browser/sbagrid.cxx b/dbaccess/source/ui/browser/sbagrid.cxx
index e8d4459..8fdc689 100644
--- a/dbaccess/source/ui/browser/sbagrid.cxx
+++ b/dbaccess/source/ui/browser/sbagrid.cxx
@@ -1113,7 +1113,7 @@ Reference< XPropertySet >  SbaGridControl::getField(sal_uInt16 nModelPos)
     }
     catch(Exception&)
     {
-        OSL_ENSURE(0,"SbaGridControl::getField Exception occured!");
+        OSL_ENSURE(0,"SbaGridControl::getField Exception occurred!");
     }
     
     return xEmptyReturn;
diff --git a/dbaccess/source/ui/browser/sbagrid.src b/dbaccess/source/ui/browser/sbagrid.src
index ca43b02..b3fd777 100644
--- a/dbaccess/source/ui/browser/sbagrid.src
+++ b/dbaccess/source/ui/browser/sbagrid.src
@@ -124,7 +124,7 @@ String STR_NO_COLUMNNAME_MATCHING
     Text [ en-US ] = "No matching column names were found.";
 };
 
-String STR_ERROR_OCCURED_WHILE_COPYING
+String STR_ERROR_OCCURRED_WHILE_COPYING
 {
     Text [ en-US ] = "An error occurred. Do you want to continue copying?";
 };
diff --git a/dbaccess/source/ui/browser/unodatbr.cxx b/dbaccess/source/ui/browser/unodatbr.cxx
index d73bbad..c61129a 100644
--- a/dbaccess/source/ui/browser/unodatbr.cxx
+++ b/dbaccess/source/ui/browser/unodatbr.cxx
@@ -2174,7 +2174,7 @@ IMPL_LINK(SbaTableQueryBrowser, OnExpandEntry, SvLBoxEntry*, _pParent)
         }
         else
             return 0L;
-                // 0 indicates that an error occured
+                // 0 indicates that an error occurred
     }
     else
     {	// we have to expand the queries or bookmarks
diff --git a/dbaccess/source/ui/control/dbtreelistbox.cxx b/dbaccess/source/ui/control/dbtreelistbox.cxx
index 8251442..5f7bad9 100644
--- a/dbaccess/source/ui/control/dbtreelistbox.cxx
+++ b/dbaccess/source/ui/control/dbtreelistbox.cxx
@@ -155,7 +155,7 @@ void DBTreeListBox::RequestingChilds( SvLBoxEntry* pParent )
     {
         if (!m_aPreExpandHandler.Call(pParent))
         {
-            // an error occured. The method calling us will reset the entry flags, so it can't be expanded again.
+            // an error occurred. The method calling us will reset the entry flags, so it can't be expanded again.
             // But we want that the user may do a second try (i.e. because he misstypes a password in this try), so
             // we have to reset these flags controlling the expand ability
             PostUserEvent(LINK(this, DBTreeListBox, OnResetEntry), pParent);
diff --git a/dbaccess/source/ui/control/tabletree.cxx b/dbaccess/source/ui/control/tabletree.cxx
index 94a35e1..6021411 100644
--- a/dbaccess/source/ui/control/tabletree.cxx
+++ b/dbaccess/source/ui/control/tabletree.cxx
@@ -199,7 +199,7 @@ void OTableTreeListBox::UpdateTableList( const Reference< XConnection >& _rxConn
     }
     catch(Exception&)
     {
-        // a non-SQLException exception occured ... simply throw an SQLException
+        // a non-SQLException exception occurred ... simply throw an SQLException
         SQLException aInfo;
         aInfo.Message = sCurrentActionError;
         throw aInfo;
diff --git a/dbaccess/source/ui/dlg/adminpages.hxx b/dbaccess/source/ui/dlg/adminpages.hxx
index 9a67752..32cfc4d 100644
--- a/dbaccess/source/ui/dlg/adminpages.hxx
+++ b/dbaccess/source/ui/dlg/adminpages.hxx
@@ -151,7 +151,7 @@ namespace dbaui
             @param	_sReturn
                 <OUT/> contains the selected name.
             @return
-                <FALSE/> if an error occured, otherwise <TRUE/>
+                <FALSE/> if an error occurred, otherwise <TRUE/>
         */
         sal_Bool getSelectedDataSource(::rtl::OUString& _sReturn,::rtl::OUString& _sCurr);
 
diff --git a/dbaccess/source/ui/inc/JoinController.hxx b/dbaccess/source/ui/inc/JoinController.hxx
index bf8b02d..e5195b2 100644
--- a/dbaccess/source/ui/inc/JoinController.hxx
+++ b/dbaccess/source/ui/inc/JoinController.hxx
@@ -150,14 +150,14 @@ namespace dbaui
         /** only defines a method to save a SQLException in d&d methods to show the error at a later state
             set the internal member m_aExceptionInfo to _rInfo
         */
-        void setErrorOccured(const ::dbtools::SQLExceptionInfo& _rInfo)
+        void setErrorOccurred(const ::dbtools::SQLExceptionInfo& _rInfo)
         {
             m_aExceptionInfo = _rInfo;
         }
         /**
             just returns the internal member and clears it
         */
-        ::dbtools::SQLExceptionInfo clearOccuredError()
+        ::dbtools::SQLExceptionInfo clearOccurredError()
         {
             ::dbtools::SQLExceptionInfo aInfo = m_aExceptionInfo;
             m_aExceptionInfo = ::dbtools::SQLExceptionInfo();
diff --git a/dbaccess/source/ui/inc/datasourcemap.hxx b/dbaccess/source/ui/inc/datasourcemap.hxx
index 4b19d28..35f8110 100644
--- a/dbaccess/source/ui/inc/datasourcemap.hxx
+++ b/dbaccess/source/ui/inc/datasourcemap.hxx
@@ -113,7 +113,7 @@ namespace dbaui
         void		clearModifiedFlag(const ::rtl::OUString& _rName);
 
         /** tell the map that a data source is scheduled to be deleted.
-            @return		id for accessing the deleted data source later. -1 if no free id existed or an error occured
+            @return		id for accessing the deleted data source later. -1 if no free id existed or an error occurred
         */
         sal_Int32	markDeleted(const ::rtl::OUString& _rName);
 
diff --git a/dbaccess/source/ui/inc/dbadmin.hxx b/dbaccess/source/ui/inc/dbadmin.hxx
index 0a31ba1..7dbb2c5 100644
--- a/dbaccess/source/ui/inc/dbadmin.hxx
+++ b/dbaccess/source/ui/inc/dbadmin.hxx
@@ -123,7 +123,7 @@ private:
     {
         AR_LEAVE_MODIFIED,		// somthing was modified and has successfully been committed
         AR_LEAVE_UNCHANGED,		// no changes were made
-        AR_KEEP					// don't leave the page (e.g. because an error occured)
+        AR_KEEP					// don't leave the page (e.g. because an error occurred)
     };
     /** apply all changes made
     */
diff --git a/dbaccess/source/ui/inc/dbu_resource.hrc b/dbaccess/source/ui/inc/dbu_resource.hrc
index c5f2afa..b1b542c 100644
--- a/dbaccess/source/ui/inc/dbu_resource.hrc
+++ b/dbaccess/source/ui/inc/dbu_resource.hrc
@@ -328,7 +328,7 @@
 #define STR_TABLEDESIGN_DBFIELDTYPES		RID_STR_GEN_START + 8
 #define STR_QRY_CONTINUE					RID_STR_GEN_START + 9
 #define STR_COLUMN_NAME						RID_STR_GEN_START + 10
-#define STR_ERROR_OCCURED_WHILE_COPYING		RID_STR_GEN_START + 11
+#define STR_ERROR_OCCURRED_WHILE_COPYING		RID_STR_GEN_START + 11
 #define STR_MISSING_TABLES_XDROP			RID_STR_GEN_START + 12
 #define STR_QUERY_DELETE_TABLE				RID_STR_GEN_START + 13
 #define STR_BUTTON_TEXT_ALL					RID_STR_GEN_START + 14
diff --git a/dbaccess/source/ui/inc/dbwiz.hxx b/dbaccess/source/ui/inc/dbwiz.hxx
index 26fe862..0a18bef 100644
--- a/dbaccess/source/ui/inc/dbwiz.hxx
+++ b/dbaccess/source/ui/inc/dbwiz.hxx
@@ -116,7 +116,7 @@ protected:
     {
         AR_LEAVE_MODIFIED,		// somthing was modified and has successfully been committed
         AR_LEAVE_UNCHANGED,		// no changes were made
-        AR_KEEP					// don't leave the page (e.g. because an error occured)
+        AR_KEEP					// don't leave the page (e.g. because an error occurred)
     };
     /** apply all changes made
     */
diff --git a/dbaccess/source/ui/inc/dbwizsetup.hxx b/dbaccess/source/ui/inc/dbwizsetup.hxx
index f416cbf..7811865 100644
--- a/dbaccess/source/ui/inc/dbwizsetup.hxx
+++ b/dbaccess/source/ui/inc/dbwizsetup.hxx
@@ -149,7 +149,7 @@ protected:
     {
         AR_LEAVE_MODIFIED,		// somthing was modified and has successfully been committed
         AR_LEAVE_UNCHANGED,		// no changes were made
-        AR_KEEP					// don't leave the page (e.g. because an error occured)
+        AR_KEEP					// don't leave the page (e.g. because an error occurred)
     };
 
 private:
diff --git a/dbaccess/source/ui/misc/RowSetDrop.cxx b/dbaccess/source/ui/misc/RowSetDrop.cxx
index 3656c8c..787aa5f 100644
--- a/dbaccess/source/ui/misc/RowSetDrop.cxx
+++ b/dbaccess/source/ui/misc/RowSetDrop.cxx
@@ -257,7 +257,7 @@ sal_Bool ORowSetImportExport::insertNewRow()
     {
         if(!m_bAlreadyAsked)
         {
-            String sAskIfContinue = String(ModuleRes(STR_ERROR_OCCURED_WHILE_COPYING));
+            String sAskIfContinue = String(ModuleRes(STR_ERROR_OCCURRED_WHILE_COPYING));
             OSQLWarningBox aDlg( m_pParent, sAskIfContinue, WB_YES_NO | WB_DEF_YES );
             if(aDlg.Execute() == RET_YES)
                 m_bAlreadyAsked = sal_True;
diff --git a/dbaccess/source/ui/querydesign/QueryDesignView.cxx b/dbaccess/source/ui/querydesign/QueryDesignView.cxx
index 1e1aa76..ab89750 100644
--- a/dbaccess/source/ui/querydesign/QueryDesignView.cxx
+++ b/dbaccess/source/ui/querydesign/QueryDesignView.cxx
@@ -247,7 +247,7 @@ namespace
                     bError = sal_True;
             }
         }
-        // check if error occured
+        // check if error occurred
         if ( bError )
             eErrorCode = eIllegalJoin;
 
@@ -2823,7 +2823,7 @@ sal_Bool OQueryDesignView::checkStatement()
 {
     sal_Bool bRet = sal_True;
     if ( m_pSelectionBox )
-        bRet = m_pSelectionBox->Save(); // an error occured so we return no
+        bRet = m_pSelectionBox->Save(); // an error occurred so we return no
     return bRet;
 }
 //-------------------------------------------------------------------------------
diff --git a/dbaccess/source/ui/querydesign/SelectionBrowseBox.cxx b/dbaccess/source/ui/querydesign/SelectionBrowseBox.cxx
index 2a2031c..e0993e9 100644
--- a/dbaccess/source/ui/querydesign/SelectionBrowseBox.cxx
+++ b/dbaccess/source/ui/querydesign/SelectionBrowseBox.cxx
@@ -640,7 +640,7 @@ sal_Bool OSelectionBrowseBox::fillColumnRef(const ::rtl::OUString& _sColumnName,
         if ( pTabWinList )
         {
             sal_uInt16 nTabCount = 0;
-            if ( !static_cast<OQueryTableView*>(getDesignView()->getTableView())->FindTableFromField(_sColumnName,_pEntry,nTabCount) ) // error occured: column not in table window
+            if ( !static_cast<OQueryTableView*>(getDesignView()->getTableView())->FindTableFromField(_sColumnName,_pEntry,nTabCount) ) // error occurred: column not in table window
             {
                 String sErrorMsg(ModuleRes(RID_STR_FIELD_DOESNT_EXIST));
                 sErrorMsg.SearchAndReplaceAscii("$name$",_sColumnName);
diff --git a/dbaccess/source/ui/querydesign/SelectionBrowseBox.hxx b/dbaccess/source/ui/querydesign/SelectionBrowseBox.hxx
index 5fa263b..6b01ccb 100644
--- a/dbaccess/source/ui/querydesign/SelectionBrowseBox.hxx
+++ b/dbaccess/source/ui/querydesign/SelectionBrowseBox.hxx
@@ -259,7 +259,7 @@ namespace dbaui
             @param	_bListAction
                 Will be set to <TRUE/> when we are in a list action otherwise <FALSE/>
             @return
-                <TRUE/> if an error occured otherwise <FALSE/>
+                <TRUE/> if an error occurred otherwise <FALSE/>
         */
         sal_Bool		saveField(const String& _sFieldName,OTableFieldDescRef& _pEntry,sal_Bool& _bListAction);
 
@@ -283,7 +283,7 @@ namespace dbaui
             @param	_bListAction
                 Will be set to <TRUE/> when we are in a list action otherwise <FALSE/>
             @return
-                <TRUE/> if an error occured otherwise <FALSE/>
+                <TRUE/> if an error occurred otherwise <FALSE/>
         */
         sal_Bool		fillColumnRef(	const ::connectivity::OSQLParseNode* _pColumnRef,
                                         const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection >& _rxConnection,
diff --git a/dbaccess/source/ui/querydesign/TableWindow.cxx b/dbaccess/source/ui/querydesign/TableWindow.cxx
index c86204f..cf7428e 100644
--- a/dbaccess/source/ui/querydesign/TableWindow.cxx
+++ b/dbaccess/source/ui/querydesign/TableWindow.cxx
@@ -205,7 +205,7 @@ BOOL OTableWindow::FillListBox()
     }
     catch(Exception&)
     {
-        OSL_ENSURE(0,"Exception occured!");
+        OSL_ENSURE(0,"Exception occurred!");
     }
     try
     {
@@ -234,7 +234,7 @@ BOOL OTableWindow::FillListBox()
     }
     catch(Exception&)
     {
-        OSL_ENSURE(0,"Exception occured!");
+        OSL_ENSURE(0,"Exception occurred!");
     }
 
     return TRUE;
diff --git a/dbaccess/source/ui/querydesign/TableWindowListBox.cxx b/dbaccess/source/ui/querydesign/TableWindowListBox.cxx
index 414a941..8d18c73 100644
--- a/dbaccess/source/ui/querydesign/TableWindowListBox.cxx
+++ b/dbaccess/source/ui/querydesign/TableWindowListBox.cxx
@@ -77,7 +77,7 @@ OTableWindowListBox::OTableWindowListBox( OTableWindow* pParent )
 void OTableWindowListBox::dragFinished( )
 {
     // first show the error msg when existing
-    m_pTabWin->getDesignView()->getController().showError(m_pTabWin->getDesignView()->getController().clearOccuredError());
+    m_pTabWin->getDesignView()->getController().showError(m_pTabWin->getDesignView()->getController().clearOccurredError());
     // second look for ui activities which should happen after d&d
     if (m_nUiEvent)
         Application::RemoveUserEvent(m_nUiEvent);
@@ -322,7 +322,7 @@ IMPL_LINK( OTableWindowListBox, DropHdl, void *, /*EMPTY_ARG*/)
     catch(const SQLException& e)
     {
         // remember the exception so that we can show them later when d&d is finished
-        m_pTabWin->getDesignView()->getController().setErrorOccured(::dbtools::SQLExceptionInfo(e));
+        m_pTabWin->getDesignView()->getController().setErrorOccurred(::dbtools::SQLExceptionInfo(e));
     }
     return 0L;
 }
diff --git a/dbaccess/source/ui/querydesign/querycontroller.cxx b/dbaccess/source/ui/querydesign/querycontroller.cxx
index 7e7d1bb..cab14b3 100644
--- a/dbaccess/source/ui/querydesign/querycontroller.cxx
+++ b/dbaccess/source/ui/querydesign/querycontroller.cxx
@@ -1614,7 +1614,7 @@ bool OQueryController::doSaveAsDoc(sal_Bool _bSaveAs)
         {
             ::dbtools::SQLExceptionInfo aInfo(e);
             showError(aInfo);
-            // an error occured so we clear the statement
+            // an error occurred so we clear the statement
             sTranslatedStmt = ::rtl::OUString();
         }
     }
diff --git a/dbaccess/source/ui/relationdesign/RelationTableView.cxx b/dbaccess/source/ui/relationdesign/RelationTableView.cxx
index 9260882..2bb3b3e 100644
--- a/dbaccess/source/ui/relationdesign/RelationTableView.cxx
+++ b/dbaccess/source/ui/relationdesign/RelationTableView.cxx
@@ -319,7 +319,7 @@ bool ORelationTableView::RemoveConnection( OTableConnection* pConn ,sal_Bool /*_
     }
     catch(Exception&)
     {
-        OSL_ENSURE(0,"ORelationTableView::RemoveConnection: Something other than SQLException occured!");
+        OSL_ENSURE(0,"ORelationTableView::RemoveConnection: Something other than SQLException occurred!");
     }
     return false;
 }
diff --git a/dbaccess/source/ui/tabledesign/TableController.cxx b/dbaccess/source/ui/tabledesign/TableController.cxx
index 982222b..9e3805c 100644
--- a/dbaccess/source/ui/tabledesign/TableController.cxx
+++ b/dbaccess/source/ui/tabledesign/TableController.cxx
@@ -1147,7 +1147,7 @@ void OTableController::alterColumns()
                         xAppend->appendByDescriptor(xNewColumn);
                     }
                     catch(const SQLException&)
-                    { // an error occured so we try to reactivate the old one
+                    { // an error occurred so we try to reactivate the old one
                         xAppend->appendByDescriptor(xColumn);
                         throw;
                     }
diff --git a/dbaccess/source/ui/uno/dbinteraction.hxx b/dbaccess/source/ui/uno/dbinteraction.hxx
index 9dcc520..2d96ec2 100644
--- a/dbaccess/source/ui/uno/dbinteraction.hxx
+++ b/dbaccess/source/ui/uno/dbinteraction.hxx
@@ -124,7 +124,7 @@ namespace dbaui
             SUPPLY_DOCUMENTSAVE
         };
         /** check if a given continuation sequence contains a given continuation type<p/>
-            @return		the index within <arg>_rContinuations</arg> of the first occurence of a continuation
+            @return		the index within <arg>_rContinuations</arg> of the first occurrence of a continuation
                         of the requested type, -1 of no such continuation exists
         */
         sal_Int32 getContinuation(
diff --git a/reportdesign/qa/complex/ReportDesignerTest.java b/reportdesign/qa/complex/ReportDesignerTest.java
old mode 100755
new mode 100644
index 7d9262a..2a7cc5a
--- a/reportdesign/qa/complex/ReportDesignerTest.java
+++ b/reportdesign/qa/complex/ReportDesignerTest.java
@@ -537,7 +537,7 @@ public class ReportDesignerTest extends ComplexTestCase {
             catch (com.sun.star.util.CloseVetoException e)
             {
                 log.println("ERROR: CloseVetoException caught");
-                log.println("CloseVetoException occured Can't close document.");
+                log.println("CloseVetoException occurred Can't close document.");
                 log.println("Message: " + e.getMessage());
             }
         }
diff --git a/reportdesign/source/core/api/ReportDefinition.cxx b/reportdesign/source/core/api/ReportDefinition.cxx
index 84943fd..2bb1007 100644
--- a/reportdesign/source/core/api/ReportDefinition.cxx
+++ b/reportdesign/source/core/api/ReportDefinition.cxx
@@ -1854,7 +1854,7 @@ void SAL_CALL OReportDefinition::load( const uno::Sequence< beans::PropertyValue
         {
             if ( i == nLastOpenMode )
                 throw lang::WrappedTargetException(
-                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "An error occured while creating the document storage." ) ),
+                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "An error occurred while creating the document storage." ) ),
                         // TODO: resource
                     *this,
                     ::cppu::getCaughtException()
diff --git a/reportdesign/source/ui/misc/UITools.cxx b/reportdesign/source/ui/misc/UITools.cxx
index ae81de8..414065b 100644
--- a/reportdesign/source/ui/misc/UITools.cxx
+++ b/reportdesign/source/ui/misc/UITools.cxx
@@ -889,7 +889,7 @@ SdrObject* isOver(const Rectangle& _rRect, SdrPage& _rPage, SdrView& _rView, boo
     return pOverlappedObj;
 }
 // -----------------------------------------------------------------------------
-bool checkArrayForOccurance(SdrObject* _pObjToCheck, SdrUnoObj* _pIgnore[], int _nListLength)
+bool checkArrayForOccurrence(SdrObject* _pObjToCheck, SdrUnoObj* _pIgnore[], int _nListLength)
 {
     for(int i=0;i<_nListLength;i++)
     {
@@ -910,7 +910,7 @@ SdrObject* isOver(const Rectangle& _rRect,SdrPage& _rPage,SdrView& _rView,bool _
 
     while( !pOverlappedObj && (pObjIter = aIter.Next()) != NULL )
     {
-        if (checkArrayForOccurance(pObjIter, _pIgnoreList, _nIgnoreListLength))
+        if (checkArrayForOccurrence(pObjIter, _pIgnoreList, _nIgnoreListLength))
         {
             continue;
         }
diff --git a/reportdesign/source/ui/report/ViewsWindow.cxx b/reportdesign/source/ui/report/ViewsWindow.cxx
index 8e6681e..4855626 100644
--- a/reportdesign/source/ui/report/ViewsWindow.cxx
+++ b/reportdesign/source/ui/report/ViewsWindow.cxx
@@ -1084,7 +1084,7 @@ void OViewsWindow::BegDragObj(const Point& _aPnt, SdrHdl* _pHdl,const OSectionVi
     // Create drag lines over all viewable Views
     // Therefore we need to identify the marked objects
     // and create temporary objects on all other views at the same position
-    // relative to its occurance.
+    // relative to its occurrence.
 
     OSL_TRACE("BegDragObj createInvisible Objects\n" );
     int nViewCount = 0;
diff --git a/reportdesign/source/ui/report/propbrw.cxx b/reportdesign/source/ui/report/propbrw.cxx
index fa1d40c..37ad025 100644
--- a/reportdesign/source/ui/report/propbrw.cxx
+++ b/reportdesign/source/ui/report/propbrw.cxx
@@ -562,7 +562,7 @@ void PropBrw::Update( OSectionView* pNewView )
     }
     catch ( Exception& )
     {
-        DBG_ERROR( "PropBrw::Update: Exception occured!" );
+        DBG_ERROR( "PropBrw::Update: Exception occurred!" );
     }
 }
 //----------------------------------------------------------------------------
@@ -584,7 +584,7 @@ void PropBrw::Update( const uno::Reference< uno::XInterface>& _xReportComponent)
         }
         catch ( Exception& )
         {
-            DBG_ERROR( "PropBrw::Update: Exception occured!" );
+            DBG_ERROR( "PropBrw::Update: Exception occurred!" );
         }
     }
 }


More information about the Libreoffice-commits mailing list
diff --git a/dbaccess/source/ui/uno/copytablewizard.cxx b/dbaccess/source/ui/uno/copytablewizard.cxx
index 360e2ca..55213d3 100644
--- a/dbaccess/source/ui/uno/copytablewizard.cxx
+++ b/dbaccess/source/ui/uno/copytablewizard.cxx
@@ -328,7 +328,7 @@ namespace dbaui
                     const Reference< XPropertySet >& _rxDestTable
                 );
 
         /** processes an error which occured during copying
 
             First, all listeners are ask. If a listener tells to cancel or continue copying, this is reported to the
             method's caller. If a listener tells to ask the user, this is done, and the user's decision is
@@ -1112,7 +1112,7 @@ bool CopyTableWizard::impl_processCopyError_nothrow( const CopyTableRowEvent& _r
     {
         SQLContext aError;
         aError.Context = *this;
-        aError.Message = String( ModuleRes( STR_ERROR_OCCURED_WHILE_COPYING ) );
+        aError.Message = String( ModuleRes( STR_ERROR_OCCURRED_WHILE_COPYING ) );
 
         ::dbtools::SQLExceptionInfo aInfo( _rEvent.Error );
         if ( aInfo.isValid() )
@@ -328,7 +328,7 @@ namespace dbaui
                 );
 
-        /** processes an error which occured during copying
+        /** processes an error which occurred during copying
 
             First, all listeners are ask. If a listener tells to cancel or continue copying, this is reported to the
diff --git a/reportdesign/source/core/misc/conditionalexpression.cxx b/reportdesign/source/core/misc/conditionalexpression.cxx
index 7f3b1d8..4956f90 100644
--- a/reportdesign/source/core/misc/conditionalexpression.cxx
+++ b/reportdesign/source/core/misc/conditionalexpression.cxx
@@ -104,16 +104,16 @@ namespace rptui
         sal_Int32 nLHSIndex( sMatchExpression.indexOf( sLHSPattern ) );
         sal_Int32 nRHSIndex( sMatchExpression.indexOf( sRHSPattern ) );
 
         // now we should have at most one occurance of $1 and $2, resp.
         OSL_ENSURE( sMatchExpression.indexOf( sLHSPattern, nLHSIndex + 1 ) == -1,
-            "ConditionalExpression::matchExpression: unsupported pattern (more than one LHS occurance)!" );
+            "ConditionalExpression::matchExpression: unsupported pattern (more than one LHS occurrence)!" );
         OSL_ENSURE( sMatchExpression.indexOf( sRHSPattern, nRHSIndex + 1 ) == -1,
-            "ConditionalExpression::matchExpression: unsupported pattern (more than one RHS occurance)!" );
+            "ConditionalExpression::matchExpression: unsupported pattern (more than one RHS occurrence)!" );
         // Also, an LHS must be present, and precede the RHS (if present)
         OSL_ENSURE( ( nLHSIndex != -1 ) && ( ( nLHSIndex < nRHSIndex ) || ( nRHSIndex == -1 ) ),
             "ConditionalExpression::matchExpression: no LHS, or an RHS preceeding the LHS - this is not supported!" );
 
         // up to the occurance of the LHS (which must exist, see above), the two expressions
         // must be identical
         if ( _rExpression.getLength() < nLHSIndex )
             return false;
@@ -123,7 +123,7 @@ namespace rptui
             // the left-most expression parts do not match
             return false;
 
         // after the occurance of the RHS (or the LHS, if there is no RHS), the two expressions
         // must be identical, too
         bool bHaveRHS( nRHSIndex != -1 );
         sal_Int32 nRightMostIndex( bHaveRHS ? nRHSIndex : nLHSIndex );
@@ -104,16 +104,16 @@ namespace rptui
         sal_Int32 nRHSIndex( sMatchExpression.indexOf( sRHSPattern ) );
 
-        // now we should have at most one occurance of $1 and $2, resp.
+        // now we should have at most one occurrence of $1 and $2, resp.
         OSL_ENSURE( sMatchExpression.indexOf( sLHSPattern, nLHSIndex + 1 ) == -1,
@@ -104,16 +104,16 @@ namespace rptui
             "ConditionalExpression::matchExpression: no LHS, or an RHS preceeding the LHS - this is not supported!" );
 
-        // up to the occurance of the LHS (which must exist, see above), the two expressions
+        // up to the occurrence of the LHS (which must exist, see above), the two expressions
         // must be identical
         if ( _rExpression.getLength() < nLHSIndex )
@@ -123,7 +123,7 @@ namespace rptui
             return false;
 
-        // after the occurance of the RHS (or the LHS, if there is no RHS), the two expressions
+        // after the occurrence of the RHS (or the LHS, if there is no RHS), the two expressions
         // must be identical, too
         bool bHaveRHS( nRHSIndex != -1 );